# switch_java_gui - the Java toolset switcher GUI
# Copyright (C) 2007 Red Hat, Inc.

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301 USA.

import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk
from switch_java_functions import *
from switch_java_globals import DATA_ROOT_DIR, PACKAGE_NAME

class mainDialog:
    def __init__(self):
        pass

    def main(self, java_identifiers, default_java, pretty_names):
        # Initialize UI.
        builder = Gtk.Builder()
        builder.add_from_file(DATA_ROOT_DIR + '/' + PACKAGE_NAME + '/' +
                            PACKAGE_NAME + '.glade')
        self.dialog = builder.get_object('dialog')
        self.dialog.set_title(TITLE_MESSAGE)
        radio_vbox = builder.get_object('radio-vbox')
        builder.get_object('instruction-label').set_text(INSTRUCTION_MESSAGE)
        builder.get_object('selection-label').set_markup('<b>'
                                                     + SELECTION_MESSAGE
                                                     + '</b>')
        ok_button = builder.get_object('ok-button')
        # Initialize alternatives list.
        self.radio_buttons = {}
        self.alternatives = {}
        for java in java_identifiers:
            if len(self.radio_buttons) == 0:
                self.radio_buttons[java] = Gtk.RadioButton.new_with_label_from_widget(None,
                                                           pretty_names[java])
                group_button = self.radio_buttons[java]
            else:
                self.radio_buttons[java] = Gtk.RadioButton.new_with_label_from_widget(group_button,
                                                           pretty_names[java])
            radio_vbox.pack_start(self.radio_buttons[java], False, False, 0)
            self.radio_buttons[java].set_use_underline(False);
            self.radio_buttons[java].show()
            self.radio_buttons[java].connect("toggled", lambda *x:
                                             ok_button.set_sensitive(True))
            self.alternatives[self.radio_buttons[java]] = java
        # Show default alternative as currently selected and give it
        # keyboard focus.
        self.radio_buttons[default_java].set_active(True)
        self.radio_buttons[default_java].grab_focus()
        ok_button.connect('clicked', self.ok_button_clicked)
        ok_button.set_sensitive(False)
        builder.get_object('cancel-button').connect('clicked',
                                                self.cancel_button_clicked)
        self.dialog.connect('delete-event', self.dialog_delete_event)
        self.dialog.connect('hide', Gtk.main_quit)
        self.dialog.set_icon_from_file(DATA_ROOT_DIR + '/pixmaps/'
                                       + PACKAGE_NAME + '.png')
        self.dialog.show()
        Gtk.main()

    def dialog_delete_event(self, *args):
        Gtk.main_quit()

    def ok_button_clicked(self, button):
        for radio_button in self.radio_buttons.values():
            if radio_button.get_active():
                switch_java(self.alternatives[radio_button])
                break
        self.dialog.hide()
        Gtk.main_quit()

    def cancel_button_clicked(self, button):
        self.dialog.hide()
        Gtk.main_quit()

    def show_dialog(self, message):
        dialog = Gtk.MessageDialog(None,
                                   Gtk.DialogFlags.MODAL
                                   | Gtk.DialogFlags.DESTROY_WITH_PARENT,
                                   Gtk.MessageType.INFO,
                                   Gtk.ButtonsType.OK,
                                   message)
        dialog.set_title(TITLE_MESSAGE)
        dialog.set_icon_from_file(DATA_ROOT_DIR + '/pixmaps/' + PACKAGE_NAME + '.png')
        dialog.run()
        dialog.destroy()
        

if __name__ == '__main__':
    mainDialog.show_dialog("test")
    